@@ -20,6 +20,11 @@ class Plugin(object):
         self.registry_hive = registry_hive
         self.as_json = as_json
 
+        self.partial_hive_path = registry_hive.partial_hive_path
+
+        # This variable should always hold the final result - in order to use it in anomaly detection and timeline gen.
+        self.entries = list()
+
     def can_run(self):
         """
         Wether the plugin can run or not, according to specific checks
@@ -32,6 +37,14 @@ class Plugin(object):
         Execute the plugin
         :return:
         """
+
+    def generate_timeline_artifacts(self):
+        """
+        Run on the output of a plugin and generate timeline entries
+        :return:
+        """
+        pass
+
     def detect_anomalies(self):
         """
         Run on the output of a plugin and detect possible anomalies
