@@ -1,3 +1,5 @@
+import attr
+
 import logbook
 
 from regipy.hive_types import SYSTEM_HIVE_TYPE
@@ -15,12 +17,15 @@ class TimezoneDataPlugin(Plugin):
     COMPATIBLE_HIVE = SYSTEM_HIVE_TYPE
 
     def run(self):
-        result = {}
+        self.entries = {}
         tzdata_subkeys = self.registry_hive.get_control_sets(TZ_DATA_PATH)
         for tzdata_subkey in tzdata_subkeys:
             tzdata = self.registry_hive.get_key(tzdata_subkey)
-            result[tzdata_subkey] = [x for x in tzdata.iter_values(as_json=self.as_json)]
-        return result
+            self.entries[tzdata_subkey] = [x for x in tzdata.iter_values(as_json=self.as_json)]
+
+        if self.as_json:
+            for k, v in self.entries.items():
+                self.entries[k] = [attr.asdict(x) for x in v]
 
 
 
